@@ -1,20 +1,24 @@
 ( cd usr/lib ; rm -rf libgpsimcli.so.0 )
 ( cd usr/lib ; ln -sf libgpsimcli.so.0.0.0 libgpsimcli.so.0 )
-( cd usr/lib ; rm -rf libgpsimcli.so )
-( cd usr/lib ; ln -sf libgpsimcli.so.0.0.0 libgpsimcli.so )
-( cd usr/lib ; rm -rf libgpsim_eXdbm.so.0 )
-( cd usr/lib ; ln -sf libgpsim_eXdbm.so.0.0.0 libgpsim_eXdbm.so.0 )
-( cd usr/lib ; rm -rf libgpsim_eXdbm.so )
-( cd usr/lib ; ln -sf libgpsim_eXdbm.so.0.0.0 libgpsim_eXdbm.so )
-( cd usr/lib ; rm -rf libgpsimgui.so.0 )
-( cd usr/lib ; ln -sf libgpsimgui.so.0.0.0 libgpsimgui.so.0 )
-( cd usr/lib ; rm -rf libgpsimgui.so )
-( cd usr/lib ; ln -sf libgpsimgui.so.0.0.0 libgpsimgui.so )
+( cd usr/lib ; rm -rf libgpsim_dspic.so )
+( cd usr/lib ; ln -sf libgpsim_dspic.so.0.0.0 libgpsim_dspic.so )
 ( cd usr/lib ; rm -rf libgpsim.so.0 )
 ( cd usr/lib ; ln -sf libgpsim.so.0.0.0 libgpsim.so.0 )
+( cd usr/lib ; rm -rf libgpsimgui.so.0 )
+( cd usr/lib ; ln -sf libgpsimgui.so.0.0.0 libgpsimgui.so.0 )
+( cd usr/lib ; rm -rf libgpsim_eXdbm.so )
+( cd usr/lib ; ln -sf libgpsim_eXdbm.so.0.0.0 libgpsim_eXdbm.so )
+( cd usr/lib ; rm -rf libgpsimgui.so )
+( cd usr/lib ; ln -sf libgpsimgui.so.0.0.0 libgpsimgui.so )
 ( cd usr/lib ; rm -rf libgpsim.so )
 ( cd usr/lib ; ln -sf libgpsim.so.0.0.0 libgpsim.so )
 ( cd usr/lib ; rm -rf libgpsim_modules.so.0 )
 ( cd usr/lib ; ln -sf libgpsim_modules.so.0.0.0 libgpsim_modules.so.0 )
+( cd usr/lib ; rm -rf libgpsim_dspic.so.0 )
+( cd usr/lib ; ln -sf libgpsim_dspic.so.0.0.0 libgpsim_dspic.so.0 )
+( cd usr/lib ; rm -rf libgpsim_eXdbm.so.0 )
+( cd usr/lib ; ln -sf libgpsim_eXdbm.so.0.0.0 libgpsim_eXdbm.so.0 )
 ( cd usr/lib ; rm -rf libgpsim_modules.so )
 ( cd usr/lib ; ln -sf libgpsim_modules.so.0.0.0 libgpsim_modules.so )
+( cd usr/lib ; rm -rf libgpsimcli.so )
+( cd usr/lib ; ln -sf libgpsimcli.so.0.0.0 libgpsimcli.so )
